pub struct FileRestoredUserEvent {
pub id: u64,
pub uuid: Uuid,
pub event_type: UserEventKind,
pub timestamp: u64,
pub info: DownloadableFileEventInfo,
}Expand description
Event emitted after a file was restored from ‘trash’.
Fields
id: u64uuid: UuidEvent UUID; hyphenated lowercased UUID V4.
event_type: UserEventKindEvent kind.
timestamp: u64Time when the event has occured, as Unix timestamp in seconds.
info: DownloadableFileEventInfoData, associated with the event.