LoginRequestPayload

Struct LoginRequestPayload 

pub struct LoginRequestPayload<'login> {
    pub email: &'login SecUtf8,
    pub password: &'login SecUtf8,
    pub two_factor_key: &'login SecUtf8,
    pub auth_version: u32,
}
Used for requests to LOGIN_PATH endpoint.

Fields

email: &'login SecUtf8

Registered user email.

password: &'login SecUtf8

Filen-processed password. Note that this is not a registered user password, but its hash. Use one of FilenPasswordWithMasterKey::from… methods to calculate it.

two_factor_key: &'login SecUtf8

Registered user 2FA key, if present. XXXXXX means no 2FA key.

auth_version: u32

Set this to a value you received from auth/info call and used to generate Filen password.