pub struct LoginRequestPayload<'login> {
pub email: &'login SecUtf8,
pub password: &'login SecUtf8,
pub two_factor_key: &'login SecUtf8,
pub auth_version: u32,
}Expand description
Used for requests to LOGIN_PATH endpoint.
Fields
email: &'login SecUtf8Registered user email.
password: &'login SecUtf8Filen-processed password. Note that this is not a registered user password, but its hash.
Use one of FilenPasswordWithMasterKey::from… methods to calculate it.
two_factor_key: &'login SecUtf8Registered user 2FA key, if present. XXXXXX means no 2FA key.
auth_version: u32Set this to a value you received from auth/info call and used to generate Filen password.