pub struct LoginResponseData {
pub api_key: SecUtf8,
pub master_keys_metadata: Option<String>,
pub private_key_metadata: Option<String>,
}Expand description
Response data for [LOGIN_PATH] endpoint.
Fields
api_key: SecUtf8Filen API key.
master_keys_metadata: Option<String>This string is a Filen metadata encrypted by the last master key and base64-encoded. It contains either a single master key string or multiple master keys strings delimited by ‘|’. Master key is in turn used to decrypt various metadata.
Empty when no keys were set (currently before the first login).
private_key_metadata: Option<String>A user’s RSA private key stored as Filen metadata encrypted by user’s last master key, containing a base64-encoded key bytes. Private key is currently used for decrypting name and metadata of the shared download folders.
Empty when no keys were set (currently before the first login).